#!/usr/bin/env python3
# SPDX-FileCopyrightText: 2020 David Faure <faure@kde.org>
# SPDX-License-Identifier: LGPL-2.0-or-later

from PyKOpeningHours import PyKOpeningHours

parser = PyKOpeningHours.OpeningHours()
parser.setExpression('Friday 11:00 am - 11:00 pm')
if parser.error() != PyKOpeningHours.Error.NoError:
    print("ERROR parsing expression:" + str(parser.error()))
else:
    print(parser.normalizedExpression())



# SPDX-FileCopyrightText: 2020 David Faure <faure@kde.org>
# SPDX-License-Identifier: LGPL-2.0-or-later

from skbuild import setup

setup(
    name="PyKOpeningHours",
    version="1.6.0",
    description="Validator for OSM opening_hours expressions",
    author='David Faure',
    license="AGPL",
    package_data={'PyKOpeningHours': ['py.typed', 'PyKOpeningHours.pyi']},
    packages=['PyKOpeningHours'],
    cmake_args=['-DVALIDATOR_ONLY=TRUE', '-DBUILD_SHARED_LIBS=FALSE', '-DCMAKE_BUILD_TYPE=Release']
)
